/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Juha Ristolainen <juha.ristolainen@codemancers.fi>
 *              Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Nick Leppänen Larsson <frals@frals.se>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import "../common/Constants.js" as Constants
import "../common"

AnalogFaceBase {
    id: clockRoot

    property var currDate: new Date;
    property int hours: currDate.getHours()
    property int minutes: currDate.getMinutes()
    property int seconds: currDate.getUTCSeconds();
    property alias innerDimension: innerCircle.width;

    signal clicked(var mouse)

    function timeChanged(now) {
        hours = now.getHours()
        minutes = now.getMinutes()
        seconds = now.getUTCSeconds();
    }        

    // FIXME 1: Replace this with UbuntuShape when the widget has landed in the SDK.
    // FIXME 2: Move this element to AnalogFaceBase.qml when the visual designs for all the pages are provided.
    Rectangle {
        id: innerCircle;

        z: parent.z + 1;
        height: units.gu(19); width: units.gu(19);
        radius: width / 2;
        anchors.centerIn: parent;
        color: Constants.coolGrey;
        antialiasing: true;        
    }

    AnalogClockHand {
        id: hourHand

        z: parent.z
        height: units.gu(12.5); width: units.gu(1);
        rotationAngle: (clockRoot.hours * 30) + (clockRoot.minutes / 2);
        antialiasing: true;
    }

    AnalogClockHand {
        id: minuteHand

        z: parent.z
        height: units.gu(14.5); width: units.gu(0.5);
        rotationAngle: clockRoot.minutes * 6;
        antialiasing: true;
    }

    AnalogClockHand {
        id: secondsHand

        z: parent.z - 1;
        height: units.gu(17); width:  units.gu(0.5)
        rotationAngle: clockRoot.seconds * 6;
        antialiasing: true;
    }    

    MouseArea {
        anchors.fill: parent
        onClicked: clockRoot.clicked(mouse);
    }
}
