/*
 * Copyright (C) 2013 Canonical Ltd
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 3 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>
 *              Nick Leppänen Larsson <frals@frals.se>
 */

import QtQuick 2.0
import Ubuntu.Components 0.1
import QtQuick.XmlListModel 2.0
import "../common/Constants.js" as Constants
import "../common"

// Qml Element to draw the easter egg (sunrise and sunset) on the analogue clock face.
Rectangle {
    id: easterEggCircle;

    // FIXME: Replace these constant values with user's location coordinates when automatic location detection is implemented.
    property real latitude: 52.01;
    property real longitude: 4.35;

    // properties to set/retrieve the sunrise and sunset times
    property alias sunriseLabel: sunriseTimeLabel.text;
    property alias sunsetLabel: sunsetTimeLabel.text;

    // properties to get the sunRiseModel XML model.
    property alias isReady: sunRiseModel.status;
    property alias model: sunRiseModel;

    opacity: 0
    color: "transparent"
    z: parent.z + 100
    visible: opacity == 0 ? false : true

    function reloadSunRiseModel () {
        sunRiseModel.reload()
    }

    // Function to form the url string to make the API call
    function getUrlString (latitude, longitude) {
        var base_url,url;
        base_url = "http://api.openweathermap.org/data/2.5/weather?";
        url = base_url + "lat=" + latitude + "&lon=" + longitude + "&mode=xml";        
        return url;
    }

    // Function to convert online data format "2013-04-20T19:40:30" to just "19:40"
    function getSunTime (data) {
        var Time = data.split('T')[1].split(':');
        return (Time[0] + ":" + Time[1]);
    }

    // TODO 1: Get the latitude and longitude using the platform API automatically instead of using static values.    
    XmlListModel {
        id: sunRiseModel

        source: getUrlString(latitude, longitude)
        query: "/current/city"

        XmlRole { name: "sunrise"; query: "sun/@rise/string()"; isKey: true }
        XmlRole { name: "sunset"; query: "sun/@set/string()"; isKey: true  }
    }
    
    Column {        
        anchors.centerIn: parent
        width: parent.width; height: childrenRect.height
        
        Label {
            id: sunriseLabel
            anchors.horizontalCenter: parent.horizontalCenter
            color: Constants.brightWhite;
            fontSize: "small";
            text: i18n.tr("Sunrise")
        }
        
        Label {
            id: sunriseTimeLabel
            anchors.horizontalCenter: parent.horizontalCenter
            color: Constants.brightWhite;
            font.pixelSize: 35;
            text: i18n.tr("loading")
        }
        
        Rectangle {
            id: sunsetsunriseDivider
            width: parent.width - units.gu(8)
            height: units.gu(0.1)
            anchors.horizontalCenter: parent.horizontalCenter            
            color: Constants.brightWhite
        }
        
        Label {
            id: sunsetTimeLabel
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            color: Constants.brightWhite;
            font.pixelSize: 35;
            text: i18n.tr("loading")
        }
        
        Label {
            id: sunsetLabel
            width: parent.width
            horizontalAlignment: Text.AlignHCenter
            color: Constants.brightWhite;
            fontSize: "small";
            text: i18n.tr("Sunset")
        }
        
    }
}
