# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Renato Araujo Oliveira Filho <renato@canonical.com>


"""clock-app autopilot tests."""

import os.path
import os

from autopilot.input import Mouse, Touch, Pointer
from autopilot.platform import model
from autopilot.testcase import AutopilotTestCase

from ubuntu_clock_app.emulators.main_window import MainWindow


class ClockAppTestCase(AutopilotTestCase):

    """A common test case class that provides several useful methods for
    clock-app tests.

    """
    if model() == 'Desktop':
        scenarios = [('with mouse', dict(input_device_class=Mouse))]
    else:
        scenarios = [('with touch', dict(input_device_class=Touch))]

    local_location = "../../ubuntu-clock-app.qml"

    def setUp(self):
        self.pointing_device = Pointer(self.input_device_class.create())
        super(ClockAppTestCase, self).setUp()
        if os.path.exists(self.local_location):
            self.launch_test_local()
        else:
            self.launch_test_installed()

    def launch_test_local(self):
        self.app = self.launch_test_application(
            "qmlscene",
            self.local_location,
            app_type='qt')

    def launch_test_installed(self):
        self.app = self.launch_test_application(
            "qmlscene",
            "/usr/share/ubuntu-clock-app/ubuntu-clock-app.qml",
            "--desktop_file_hint=/usr/share/applications/ubuntu-clock-app.desktop",
            app_type='qt')
            
    def get_tabs(self):
        return self.main_window.get_object("Tabs", "rootTabs")
        
    """Function to switch to the next tab """
    def move_to_next_tab(self):
        main_view = self.main_window.get_qml_view()
        tabs = self.get_tabs()
        currentTab = tabs.selectedTabIndex
        
        start_x = main_view.x + main_view.width * 0.50
        stop_x = main_view.x + + main_view.width * 0.20
        y_line = main_view.y + main_view.height * 0.05
        
        self.pointing_device.drag(start_x, y_line, stop_x, y_line)
        self.pointing_device.click()
        self.pointing_device.click()    

    @property
    def main_window(self):
        return MainWindow(self.app)
