# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Copyright (C) 2013 Canonical Ltd
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License version 3 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# Authored by: Nekhelesh Ramananthan <krnekhelesh@gmail.com>

"""Tests for the Clock App - Stopwatch"""

from __future__ import absolute_import

from testtools.matchers import Equals, NotEquals
from autopilot.matchers import Eventually

from ubuntu_clock_app.tests import ClockAppTestCase

class TestStopwatch(ClockAppTestCase):
    """Tests the stopwatch page features"""

    """ This is needed to wait for the application to start.
        In the testfarm, the application may take some time to show up."""
    def setUp(self):
        super(TestStopwatch, self).setUp()        
        self.assertThat(self.main_window.get_qml_view().visible, Eventually(Equals(True)))
        
        # Moving from Clock page -> Alarm Page -> Timer Page -> Stopwatch Page
        self.move_to_next_tab()
        self.move_to_next_tab()
        self.move_to_next_tab()
        
        # Test if the current Tab is the Timer Tab
        CurrentTab = self.main_window.get_object("Tab", "StopwatchTab")
        self.assertThat(CurrentTab.title, Eventually(Equals("Stopwatch")))

    def tearDown(self):
        super(TestStopwatch, self).tearDown()      
    
    def test_start_stopwatch(self):
        """The start button must start the stopwatch"""    
        #Test if button has label "Start"
        self.assertThat(self.main_window.get_stopwatch_button().text, Eventually(Equals('Start')))
        
        self.pointing_device.move_to_object(self.main_window.get_stopwatch_button())
        self.pointing_device.click()
        
        # Test if the stopwatch label changes
        self.assertThat(self.main_window.get_stopwatch_button().text, Eventually(Equals('Stop')))
        self.assertThat(self.main_window.get_lap_button().text, Eventually(Equals('Lap')))
        stopwatch_label_before = self.main_window.get_stopwatch_label().text
        stopwatch_label_after = lambda: self.main_window.get_stopwatch_label().text
        self.assertThat(stopwatch_label_after, Eventually(NotEquals(stopwatch_label_before)))        
        
    def test_stop_stopwatch(self):
        """The stop button must stop the stopwatch"""
        
        self.test_start_stopwatch()
        
        #Test if button has label "Stop"
        self.assertThat(self.main_window.get_stopwatch_button().text, Eventually(Equals('Stop')))        
        
        self.pointing_device.move_to_object(self.main_window.get_stopwatch_button())
        self.pointing_device.click()
        
        self.assertThat(self.main_window.get_stopwatch_button().text, Eventually(Equals('Start')))
        self.assertThat(self.main_window.get_lap_button().text, Eventually(Equals('Reset')))
        
        stopwatch_label_before = self.main_window.get_stopwatch_label().text
        stopwatch_label_after = lambda: self.main_window.get_stopwatch_label().text
        self.assertThat(stopwatch_label_after, Eventually(Equals(stopwatch_label_before)))
        
    def test_reset_stopwatch(self):
        """The reset button must reset the stopwatch"""    
        
        self.test_stop_stopwatch()        
        self.assertThat(self.main_window.get_stopwatch_label().text, Eventually(Equals('00:00.0')))
        
    def test_lap_stopwatch(self):
        """The lap button must create a new stopwatch lap"""    
        
        self.test_start_stopwatch() 
               
        lap_count_before = self.main_window.get_lap_count().text
        self.pointing_device.move_to_object(self.main_window.get_lap_button())
        self.pointing_device.click()
        lap_count_after = lambda: self.main_window.get_lap_count().text
        
        self.assertThat(lap_count_after, Eventually(NotEquals(lap_count_before)))        
